@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 
+import os
 import sys
 import time
 import logging
@@ -17,7 +18,7 @@ except ImportError:
         def emit(self, record):
             pass
 
-__version__ = '1.1.3'
+__version__ = '1.2.0'
 
 # Elasticsearch versions supported
 version_max  = (2, 0, 0)
@@ -33,13 +34,13 @@ DEFAULT_ARGS = {
     'ssl': False,
     'timeout': 30,
     'prefix': 'logstash-',
-    'separator': '.',
     'curation_style': 'time',
     'time_unit': 'days',
     'max_num_segments': 2,
     'dry_run': False,
     'debug': False,
     'log_level': 'INFO',
+    'logformat': 'Default',
     'show_indices': False,
     'wait_for_completion': True,
     'ignore_unavailable': False,
@@ -70,6 +71,7 @@ def make_parser():
     parser.add_argument('-D', '--debug', dest='debug', action='store_true', help='Debug mode', default=DEFAULT_ARGS['debug'])
     parser.add_argument('--loglevel', dest='log_level', action='store', help='Log level', default=DEFAULT_ARGS['log_level'], type=str)
     parser.add_argument('-l', '--logfile', dest='log_file', help='log file', type=str)
+    parser.add_argument('--logformat', dest='logformat', help='Log output format [default|logstash]. Default: default', default=DEFAULT_ARGS['logformat'], type=str)
 
     # Command sub_parsers
     subparsers = parser.add_subparsers(
@@ -80,8 +82,8 @@ def make_parser():
     parser_alias = subparsers.add_parser('alias', help='Aliasing operations')
     parser_alias.set_defaults(func=alias_loop)
     parser_alias.add_argument('-p', '--prefix', help='Prefix for the indices. Indices that do not have this prefix are skipped. Default: logstash-', default=DEFAULT_ARGS['prefix'])
-    parser_alias.add_argument('-s', '--separator', help='TIME_UNIT separator. Default: .', default=DEFAULT_ARGS['separator'])
-    parser_alias.add_argument('-T', '--time-unit', dest='time_unit', action='store', help='Unit of time to reckon by: [days, hours] Default: days',
+    parser_alias.add_argument('--timestring', help="Python strftime string to match your index definition, e.g. 2014.07.15 would be %%Y.%%m.%%d", type=str, default=None)
+    parser_alias.add_argument('-T', '--time-unit', dest='time_unit', action='store', help='Unit of time to reckon by: [hours|days|weeks] Default: days',
                         default=DEFAULT_ARGS['time_unit'], type=str)
     parser_alias.add_argument('--exclude-pattern', help='Exclude indices matching provided pattern, e.g. 2014.06.08', type=str, default=None)
     parser_alias.add_argument('--alias', required=True, help='Alias name', type=str)
@@ -93,8 +95,8 @@ def make_parser():
     parser_allocation = subparsers.add_parser('allocation', help='Apply required index routing allocation rule')
     parser_allocation.set_defaults(func=command_loop)
     parser_allocation.add_argument('-p', '--prefix', help='Prefix for the indices. Indices that do not have this prefix are skipped. Default: logstash-', default=DEFAULT_ARGS['prefix'])
-    parser_allocation.add_argument('-s', '--separator', help='TIME_UNIT separator. Default: .', default=DEFAULT_ARGS['separator'])
-    parser_allocation.add_argument('-T', '--time-unit', dest='time_unit', action='store', help='Unit of time to reckon by: [days, hours] Default: days', default=DEFAULT_ARGS['time_unit'], type=str)
+    parser_allocation.add_argument('--timestring', help="Python strftime string to match your index definition, e.g. 2014.07.15 would be %%Y.%%m.%%d", type=str, default=None)
+    parser_allocation.add_argument('-T', '--time-unit', dest='time_unit', action='store', help='Unit of time to reckon by: [hours|days|weeks] Default: days', default=DEFAULT_ARGS['time_unit'], type=str)
     parser_allocation.add_argument('--older-than', required=True, help='Apply rule to indices older than n TIME_UNITs', type=int)
     parser_allocation.add_argument('--rule', required=True, help='Routing allocation rule to apply, e.g. tag=ssd', type=str)
     parser_allocation.add_argument('--exclude-pattern', help='Exclude indices matching provided pattern, e.g. 2014.06.08', type=str, default=None)
@@ -103,8 +105,8 @@ def make_parser():
     parser_bloom = subparsers.add_parser('bloom', help='Disable bloom filter cache for indices')
     parser_bloom.set_defaults(func=command_loop)
     parser_bloom.add_argument('-p', '--prefix', help='Prefix for the indices. Indices that do not have this prefix are skipped. Default: logstash-', default=DEFAULT_ARGS['prefix'])
-    parser_bloom.add_argument('-s', '--separator', help='TIME_UNIT separator. Default: .', default=DEFAULT_ARGS['separator'])
-    parser_bloom.add_argument('-T', '--time-unit', dest='time_unit', action='store', help='Unit of time to reckon by: [days, hours] Default: days', default=DEFAULT_ARGS['time_unit'], type=str)
+    parser_bloom.add_argument('--timestring', help="Python strftime string to match your index definition, e.g. 2014.07.15 would be %%Y.%%m.%%d", type=str, default=None)
+    parser_bloom.add_argument('-T', '--time-unit', dest='time_unit', action='store', help='Unit of time to reckon by: [hours|days|weeks] Default: days', default=DEFAULT_ARGS['time_unit'], type=str)
     parser_bloom.add_argument('--older-than', required=True, help='Disable bloom filter cache for indices older than n TIME_UNITs', type=int)
     parser_bloom.add_argument('--exclude-pattern', help='Exclude indices matching provided pattern, e.g. 2014.06.08', type=str, default=None)
 
@@ -112,8 +114,8 @@ def make_parser():
     parser_close = subparsers.add_parser('close', help='Close indices')
     parser_close.set_defaults(func=command_loop)
     parser_close.add_argument('-p', '--prefix', help='Prefix for the indices. Indices that do not have this prefix are skipped. Default: logstash-', default=DEFAULT_ARGS['prefix'])
-    parser_close.add_argument('-s', '--separator', help='TIME_UNIT separator. Default: .', default=DEFAULT_ARGS['separator'])
-    parser_close.add_argument('-T', '--time-unit', dest='time_unit', action='store', help='Unit of time to reckon by: [days, hours] Default: days', default=DEFAULT_ARGS['time_unit'], type=str)
+    parser_close.add_argument('--timestring', help="Python strftime string to match your index definition, e.g. 2014.07.15 would be %%Y.%%m.%%d", type=str, default=None)
+    parser_close.add_argument('-T', '--time-unit', dest='time_unit', action='store', help='Unit of time to reckon by: [hours|days|weeks] Default: days', default=DEFAULT_ARGS['time_unit'], type=str)
     parser_close.add_argument('--older-than', required=True, help='Close indices older than n TIME_UNITs', type=int)
     parser_close.add_argument('--exclude-pattern', help='Exclude indices matching provided pattern, e.g. 2014.06.08', type=str, default=None)
 
@@ -121,8 +123,8 @@ def make_parser():
     parser_delete = subparsers.add_parser('delete', help='Delete indices')
     parser_delete.set_defaults(func=command_loop)
     parser_delete.add_argument('-p', '--prefix', help='Prefix for the indices. Indices that do not have this prefix are skipped. Default: logstash-', default=DEFAULT_ARGS['prefix'])
-    parser_delete.add_argument('-s', '--separator', help='TIME_UNIT separator. Default: .', default=DEFAULT_ARGS['separator'])
-    parser_delete.add_argument('-T', '--time-unit', dest='time_unit', action='store', help='Unit of time to reckon by: [days, hours] Default: days', default=DEFAULT_ARGS['time_unit'], type=str)
+    parser_delete.add_argument('--timestring', help="Python strftime string to match your index definition, e.g. 2014.07.15 would be %%Y.%%m.%%d", type=str, default=None)
+    parser_delete.add_argument('-T', '--time-unit', dest='time_unit', action='store', help='Unit of time to reckon by: [hours|days|weeks] Default: days', default=DEFAULT_ARGS['time_unit'], type=str)
     parser_delete.add_argument('--exclude-pattern', help='Exclude indices matching provided pattern, e.g. 2014.06.08', type=str, default=None)
     delete_group = parser_delete.add_mutually_exclusive_group()
     delete_group.add_argument('--older-than', help='Delete indices older than n TIME_UNITs', type=int)
@@ -132,8 +134,8 @@ def make_parser():
     parser_optimize = subparsers.add_parser('optimize', help='Optimize indices')
     parser_optimize.set_defaults(func=command_loop)
     parser_optimize.add_argument('-p', '--prefix', help='Prefix for the indices. Indices that do not have this prefix are skipped. Default: logstash-', default=DEFAULT_ARGS['prefix'])
-    parser_optimize.add_argument('-s', '--separator', help='TIME_UNIT separator. Default: .', default=DEFAULT_ARGS['separator'])
-    parser_optimize.add_argument('-T', '--time-unit', dest='time_unit', action='store', help='Unit of time to reckon by: [days, hours] Default: days', default=DEFAULT_ARGS['time_unit'], type=str)
+    parser_optimize.add_argument('--timestring', help="Python strftime string to match your index definition, e.g. 2014.07.15 would be %%Y.%%m.%%d", type=str, default=None)
+    parser_optimize.add_argument('-T', '--time-unit', dest='time_unit', action='store', help='Unit of time to reckon by: [hours|days|weeks] Default: days', default=DEFAULT_ARGS['time_unit'], type=str)
     parser_optimize.add_argument('--older-than', required=True, help='Optimize indices older than n TIME_UNITs', type=int)
     parser_optimize.add_argument('--max_num_segments', help='Optimize segment count to n segments per shard.', default=DEFAULT_ARGS['max_num_segments'], type=int)
 
@@ -151,8 +153,8 @@ def make_parser():
     parser_snapshot = subparsers.add_parser('snapshot', help='Take snapshots of indices (Backup)')
     parser_snapshot.set_defaults(func=command_loop)
     parser_snapshot.add_argument('-p', '--prefix', help='Prefix for the indices. Indices that do not have this prefix are skipped. Default: logstash-', default=DEFAULT_ARGS['prefix'])
-    parser_snapshot.add_argument('-s', '--separator', help='TIME_UNIT separator. Default: .', default=DEFAULT_ARGS['separator'])
-    parser_snapshot.add_argument('-T', '--time-unit', dest='time_unit', action='store', help='Unit of time to reckon by: [days, hours] Default: days', default=DEFAULT_ARGS['time_unit'], type=str)
+    parser_snapshot.add_argument('--timestring', help="Python strftime string to match your index definition, e.g. 2014.07.15 would be %%Y.%%m.%%d", type=str, default=None)
+    parser_snapshot.add_argument('-T', '--time-unit', dest='time_unit', action='store', help='Unit of time to reckon by: [hours|days|weeks] Default: days', default=DEFAULT_ARGS['time_unit'], type=str)
     parser_snapshot.add_argument('--exclude-pattern', help='Exclude indices matching provided pattern, e.g. 2014.06.08', type=str, default=None)
     parser_snapshot.add_argument('--repository', required=True, type=str, help='Repository name')
 
@@ -172,6 +174,13 @@ def make_parser():
 
     return parser
 
+class Whitelist(logging.Filter):
+    def __init__(self, *whitelist):
+        self.whitelist = [logging.Filter(name) for name in whitelist]
+
+    def filter(self, record):
+        return any(f.filter(record) for f in self.whitelist)
+
 def show(client, **kwargs):
     if kwargs['show_indices']:
         for index_name in get_indices(client, kwargs['prefix']):
@@ -182,16 +191,21 @@ def show(client, **kwargs):
             print('{0}'.format(snapshot))
         sys.exit(0)
 
-def get_index_time(index_timestamp, separator='.'):
+def get_index_time(index_timestamp, timestring):
     """ Gets the time of the index.
 
-    :param index_timestamp: A string on the format YYYY.MM.DD[.HH]
+    :param index_timestamp: A string of the format timestring
     :return The creation time (datetime) of the index.
     """
-    try:
-        return datetime.strptime(index_timestamp, separator.join(('%Y', '%m', '%d', '%H')))
-    except ValueError:
-        return datetime.strptime(index_timestamp, separator.join(('%Y', '%m', '%d')))
+    # Compensate for week of year by appending '%w' to the timestring
+    # and '1' (Monday) to index_timestamp
+    if '%W' in timestring:
+        timestring += '%w'
+        index_timestamp += '1'
+    elif '%U' in timestring:
+        timestring += '%w'
+        index_timestamp += '1'
+    return datetime.strptime(index_timestamp, timestring)
 
 def get_indices(client, prefix='logstash-', exclude_pattern=None):
     """Return a sorted list of indices matching prefix"""
@@ -262,57 +276,47 @@ def get_object_list(client, data_type='index', prefix='logstash-', repository=No
     else:
         return object_list
     
-def find_expired_data(client, object_list=[], utc_now=None, time_unit='days', older_than=999999, prefix='logstash-', separator='.', **kwargs):
+def find_expired_data(client, object_list=[], utc_now=None, time_unit='days', older_than=999999, prefix='logstash-', timestring=None, **kwargs):
     """ Generator that yields expired objects (indices or snapshots).
-
-    :return: Yields tuples on the format ``(name, expired_by)`` where name
-        is the name of the expired object and expired_by is the interval (timedelta) that the
-        object was expired by.
+    
+    :return: Yields a list of indices older than n `time_unit`s
     """
     # time-injection for test purposes only
     utc_now = utc_now if utc_now else datetime.utcnow()
     # reset to start of the period to be sure we are not retiring a human by mistake
     utc_now = utc_now.replace(minute=0, second=0, microsecond=0)
-
-    if time_unit == 'hours':
-        required_parts = 4
-    else:
-        required_parts = 3
+    
+    if time_unit == 'days':
         utc_now = utc_now.replace(hour=0)
+    if time_unit == 'weeks':
+        # Since week math always uses Monday as the start of the week,
+        # this work-around resets utc_now to be Monday of the current week.
+        weeknow = utc_now.strftime('%Y-%W')
+        utc_now = get_index_time(weeknow, '%Y-%W')
 
+    # This cutoff must be a multiple of time_units
     cutoff = utc_now - timedelta(**{time_unit: (older_than - 1)})
-
+    
     for object_name in object_list:
-
-        unprefixed_object_name = object_name[len(prefix):]
-
-        # find the timestamp parts (i.e ['2011', '01', '05'] from '2011.01.05') using the configured separator
-        parts = unprefixed_object_name.split(separator)
-
-        # verify we have a valid cutoff - hours for 4-part indices, days for 3-part
-        if len(parts) != required_parts:
-            logger.debug('Skipping {0} because it is of a type (hourly or daily) that I\'m not asked to evaluate.'.format(object_name))
-            continue
+    
+        index_timestamp = object_name[len(prefix):]
 
         try:
-            object_time = get_index_time(unprefixed_object_name, separator=separator)
+            object_time = get_index_time(index_timestamp, timestring)
         except ValueError:
-            logger.error('Could not find a valid timestamp for {0}'.format(object_name))
+            logger.error('Could not find a valid timestamp for {0} with timestring {1}'.format(object_name, timestring))
             continue
-
+    
         # if the index is older than the cutoff
         if object_time < cutoff:
-            yield object_name, cutoff-object_time
-
+            yield object_name
         else:
-            logger.info('{0} is {1} above the cutoff.'.format(object_name, object_time-cutoff))
+            logger.info('{0} is within the threshold period ({1} {2}).'.format(object_name, older_than, time_unit))
 
-def find_overusage_indices(client, disk_space=2097152.0, separator='.', prefix='logstash-', **kwargs):
+def find_overusage_indices(client, disk_space=2097152.0, prefix='logstash-', **kwargs):
     """ Generator that yields over usage indices.
 
-    :return: Yields tuples on the format ``(index_name, 0)`` where index_name
-    is the name of the expired index. The second element is only here for
-    compatiblity reasons.
+    :return: Yields a list of indices to delete based on space consumed, starting with the oldest.
     """
 
     disk_usage = 0.0
@@ -490,16 +494,15 @@ def snap_latest_indices(client, most_recent=0, prefix='logstash-', dry_run=False
     """Snapshot 'count' most recent indices matching prefix"""
     indices = [] # initialize...
     indices = get_indices(client, prefix)
+    prepend = "DRY RUN: " if dry_run else ''
     for index_name in indices[-most_recent:]:
-        if dry_run:
-            logger.info('Would have attempted creating snapshot for {0}.'.format(index_name))
-            continue
+        if not index_closed(client, index_name):
+            logger.info(prepend + 'Attempting to create snapshot for {0}...'.format(index_name))
         else:
-            if not index_closed(client, index_name):
-                logger.info('Attempting to create snapshot for {0}...'.format(index_name))
-            else:
-                logger.warn('Unable to perform snapshot on closed index {0}'.format(index_name))
-                continue
+            logger.warn(prepend + 'Unable to perform snapshot on closed index {0}'.format(index_name))
+            continue
+        if dry_run:
+            continue # Don't do the work on a dry run
         
         skipped = _create_snapshot(client, index_name, prefix, **kwargs)
             
@@ -507,10 +510,11 @@ def snap_latest_indices(client, most_recent=0, prefix='logstash-', dry_run=False
             continue
         # if no error was raised and we got here that means the operation succeeded
         logger.info('Snapshot operation for index {0} succeeded.'.format(index_name))
-    logger.info('Snapshot \'latest\' {0} indices operations completed.'.format(most_recent))
+    logger.info(prepend + 'Snapshot \'latest\' {0} indices operations completed.'.format(most_recent))
 
 def alias_loop(client, dry_run=False, **kwargs):
-    logging.info("Beginning ALIAS operations...")
+    prepend = "DRY RUN: " if dry_run else ''
+    logging.info(prepend + "Beginning ALIAS operations...")
     if kwargs['alias_older_than']:
         kwargs['older_than'] = kwargs['alias_older_than']
         op = _add_to_alias
@@ -521,23 +525,22 @@ def alias_loop(client, dry_run=False, **kwargs):
         words = ['remove', 'from', 'removed']
     index_list = get_object_list(client, **kwargs)
     expired_indices = find_expired_data(client, object_list=index_list, **kwargs)
-    for index_name, expiration in expired_indices:
+    for index_name in expired_indices:
+        logger.info(prepend + 'Attempting to {0} index {1} {2} alias {3}.'.format(words[0], index_name, words[1], kwargs['alias']))
         if dry_run:
-            logger.info('Would have attempted to {0} index {1} {2} alias {3} because it is {4} older than the calculated cutoff.'.format(words[0], index_name, words[1], kwargs['alias'], expiration))
             continue
-        else:
-            logger.info('Attempting to {0} index {1} {2} alias {3} because it is {4} older than cutoff.'.format(words[0], index_name, words[1], kwargs['alias'], expiration))
 
         skipped = op(client, index_name, **kwargs)
         if skipped:
             continue
         # if no error was raised and we got here that means the operation succeeded
         logger.info('{0}: Successfully {1} {2} alias {3}.'.format(index_name, words[2], words[1], kwargs['alias']))
-    logger.info('Index ALIAS operations completed.')
+    logger.info(prepend + 'Index ALIAS operations completed.')
 
 def command_loop(client, dry_run=False, **kwargs):
+    prepend = "DRY RUN: " if dry_run else ''
     command = kwargs['command']
-    logging.info("Beginning {0} operations...".format(command.upper()))
+    logging.info(prepend + "Beginning {0} operations...".format(command.upper()))
     op, words = OP_MAP[command]
     by_space = kwargs['disk_space'] if 'disk_space' in kwargs else False
     if command == 'delete' and by_space:
@@ -555,18 +558,13 @@ def command_loop(client, dry_run=False, **kwargs):
         index_list = get_object_list(client, **kwargs)
         expired_indices = find_expired_data(client, object_list=index_list, **kwargs)
 
-    for index_name, expiration in expired_indices:
-        if dry_run and not by_space:
-            logger.info('Would have attempted {0} index {1} because it is {2} older than the calculated cutoff.'.format(words['gerund'].lower(), index_name, expiration))
-            continue
-        elif dry_run and by_space:
-            logger.info('Would have attempted {0} index {1} due to space constraints.'.format(words['gerund'].lower(), index_name))
-            continue
-
+    for index_name in expired_indices:
         if not by_space:
-            logger.info('Attempting to {0} index {1} because it is {2} older than cutoff.'.format(words['op'], index_name, expiration))
+            logger.info(prepend + 'Attempting to {0} index {1}.'.format(words['op'], index_name))
         else:
-            logger.info('Attempting to {0} index {1} due to space constraints.'.format(words['op'].lower(), index_name))
+            logger.info(prepend + 'Attempting to {0} index {1} due to space constraints.'.format(words['op'].lower(), index_name))
+        if dry_run:
+            continue # Don't act on dry run
 
         skipped = op(client, index_name, **kwargs)
 
@@ -579,7 +577,7 @@ def command_loop(client, dry_run=False, **kwargs):
         w = words['op'][:-4]
     else:
         w = words['op']
-    logger.info('{0} index operations completed.'.format(w.upper()))
+    logger.info(prepend + '{0} index operations completed.'.format(w.upper()))
 
 def get_segmentcount(client, index_name):
     """Return a list of shardcount, segmentcount"""
@@ -592,6 +590,29 @@ def get_segmentcount(client, index_name):
             totalshards += 1
     return totalshards, segmentcount
 
+def validate_timestring(timestring, time_unit):
+    """
+    Validate that the appropriate element(s) for time_unit are in the timestring.
+    e.g. If "weeks", we should see %U or %W, if hours %H, etc.
+    """
+    fail = True
+    if time_unit == 'hours':
+        if '%H' in timestring:
+            fail = False
+    elif time_unit == 'days':
+        if '%d' in timestring:
+            fail = False
+    elif time_unit == 'weeks':
+        if '%W' in timestring:
+            fail = False
+        elif '%U' in timestring:
+            fail = False
+    if fail:
+        print('Timestring {0} does not match time unit {1}'.format(timestring, time_unit))
+        sys.exit(1)
+    return
+
+    
 def main():
     start = time.time()
 
@@ -615,7 +636,6 @@ def main():
 
     if arguments.command == 'show':
         # Do not log and force dry-run if we opt to show indices or snapshots.
-        import os
         arguments.log_file = os.devnull
         arguments.dry_run = True
         if not arguments.show_indices and not arguments.show_snapshots:
@@ -640,18 +660,33 @@ def main():
         if not isinstance(numeric_log_level, int):
             raise ValueError('Invalid log level: %s' % arguments.log_level)
     
+    if arguments.logformat == 'logstash':
+        os.environ['TZ'] = 'UTC'
+        time.tzset()
+        format_string = '{"@timestamp":"%(asctime)s.%(msecs)03dZ", "loglevel":"%(levelname)s", "function":"%(funcName)s", "linenum":"%(lineno)d", "message":"%(message)s"}'
+        date_string = '%Y-%m-%dT%H:%M:%S'
+    else:
+        format_string = '%(asctime)s %(levelname)-9s %(funcName)22s:%(lineno)-4d %(message)s'
+        date_string = None
     logging.basicConfig(level=numeric_log_level,
-                        format='%(asctime)s.%(msecs)03d %(levelname)-9s %(funcName)22s:%(lineno)-4d %(message)s',
-                        datefmt="%Y-%m-%dT%H:%M:%S",
+                        format=format_string,
+                        datefmt=date_string,
                         stream=open(arguments.log_file, 'a') if arguments.log_file else sys.stderr)
+
+
+    # Filter out logging from Elasticsearch and associated modules by default
+    if not arguments.debug:
+        for handler in logging.root.handlers:
+            handler.addFilter(Whitelist('root', '__main__'))
+
+    # Setting up NullHandler to handle nested elasticsearch.trace Logger instance in elasticsearch python client
+    logging.getLogger('elasticsearch.trace').addHandler(NullHandler())
+
     logging.info("Job starting...")
 
     if arguments.dry_run:
         logging.info("DRY RUN MODE.  No changes will be made.")
 
-    # Setting up NullHandler to handle nested elasticsearch.trace Logger instance in elasticsearch python client
-    logging.getLogger('elasticsearch.trace').addHandler(NullHandler())
-
     # Override the timestamp in case the end-user doesn't.
     if timeout_override and arguments.timeout == 30:
         logger.info('Default timeout of 30 seconds is too low for command {0}.  Overriding to 21,600 seconds (6 hours).'.format(arguments.command.upper()))
@@ -666,6 +701,17 @@ def main():
         logger.fatal('Master-only flag detected. Connected to non-master node. Aborting.')
         sys.exit(1)
 
+    if arguments.timestring:
+        validate_timestring(arguments.timestring, arguments.time_unit)
+    else: # Set default timestrings
+        if arguments.time_unit == 'hours':
+            arguments.timestring = '%Y.%m.%d.%H'
+        elif arguments.time_unit == 'days':
+            arguments.timestring = '%Y.%m.%d'
+        elif arguments.time_unit == 'weeks':
+            arguments.timestring = '%Y.%W'
+        logging.debug("Setting default timestring for {0} to {1}".format(arguments.time_unit, arguments.timestring))
+    logging.debug("Matching indices with pattern: {0}{1}".format(arguments.prefix,arguments.timestring))
     # Execute the command specified in the arguments
     argdict = arguments.__dict__
     logging.debug("argdict = {0}".format(argdict))
